.. automodule:: xclim.indicators.atmos
   :members:
   :undoc-members:
   :imported-members:

.. automodule:: xclim.indicators.land
   :members:
   :undoc-members:
   :imported-members:

.. automodule:: xclim.indicators.seaIce
   :members:
   :undoc-members:
   :imported-members:
